<?php

namespace Drupal\harmonize\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Entity Settings entity.
 *
 * @ConfigEntityType(
 *   id = "harmonize_entity_settings",
 *   label = @Translation("Harmonize settings"),
 *   handlers = {},
 *   config_prefix = "entity_settings",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *     "populate_variables" = "populate_variables",
 *     "display_filtering" = "display_filtering",
 *     "display_settings" = "display_settings",
 *   },
 *   config_export = {
 *     "id",
 *     "populate_variables",
 *     "display_filtering",
 *     "display_settings",
 *   },
 *   links = {}
 * )
 */
class EntitySettings extends ConfigEntityBase implements EntitySettingsInterface {

  /**
   * The Entity settings ID.
   *
   * @var string
   */
  protected string $id;

  /**
   * {@inheritdoc}
   */
  public function setPopulateVariables(bool $value) : EntitySettingsInterface {
    $this->set('populate_variables', $value);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getPopulateVariables() : ?bool {
    return $this->get('populate_variables');
  }

  /**
   * {@inheritdoc}
   */
  public function setAllowDisplayFiltering(bool $value) : EntitySettingsInterface {
    $this->set('display_filtering', $value);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getAllowDisplayFiltering() : ?bool {
    return $this->get('display_filtering');
  }

  /**
   * {@inheritdoc}
   */
  public function setDisplaySettings(array $value) : EntitySettingsInterface {
    $this->set('display_settings', $value);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getDisplaySettings() : ?array {
    return $this->get('display_settings');
  }

}
