<?php

namespace Drupal\harmonize\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface for defining Entity settings entities.
 */
interface EntitySettingsInterface extends ConfigEntityInterface {

  /**
   * Set whether variables population is enabled.
   *
   * @param bool $value
   *   Set to TRUE or FALSE.
   */
  public function setPopulateVariables(bool $value) : EntitySettingsInterface;

  /**
   * Get whether variables population is enabled.
   *
   * @return ?bool
   *   Returns TRUE if variables population is enabled. Returns FALSE otherwise.
   */
  public function getPopulateVariables() : ?bool;

  /**
   * Set whether display filtering is enabled.
   *
   * @param bool $value
   *   Set to TRUE or FALSE.
   */
  public function setAllowDisplayFiltering(bool $value) : EntitySettingsInterface;

  /**
   * Get whether display filtering is allowed.
   *
   * @return ?bool
   *   Returns TRUE if display filtering is enabled. Returns FALSE otherwise.
   */
  public function getAllowDisplayFiltering() : ?bool;

  /**
   * Set display settings.
   *
   * @param array $value
   *   Set the array of display settings.
   */
  public function setDisplaySettings(array $value) : EntitySettingsInterface;

  /**
   * Get display settings.
   *
   * @return ?array
   *   Returns TRUE if variables population is enabled. Returns FALSE otherwise.
   */
  public function getDisplaySettings() : ?array;

}
