<?php

namespace Drupal\harmonize\Service\FormTuner;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\harmonize\Entity\EntitySettings;
use Drupal\harmonize\Entity\EntitySettingsInterface;

/**
 * Base class for Form Tuners.
 *
 * Form Tuners are quite simply services that are meant to alter core Drupal forms.
 *
 * @package Drupal\harmonize\Service\FormTuner
 */
abstract class FormTuner {

  /**
   * Alter form.
   *
   * @param array $form
   *   Render array of the form being altered.
   * @param FormStateInterface $formState
   *   Form state.
   * @param EntityInterface $formEntity
   *   Form entity.
   */
  abstract public function alter(array &$form, FormStateInterface $formState, EntityInterface $formEntity) : void;

  /**
   * Load Harmonize Entity Settings for a given entity type & bundle.
   *
   * @param string $entityTypeId
   *   The entity type to load settings for.
   * @param string $bundle
   *   The bundle to load settings for.
   * @param bool $createOnFailure
   *   Whether to create a new entity if we fail to find settings.
   *
   * @return ?EntitySettingsInterface
   *   Return an instance of Entity Settings or NULL if not found.
   */
  protected static function loadEntitySettings(string $entityTypeId, string $bundle, bool $createOnFailure = FALSE) : ?EntitySettingsInterface {
    if ($createOnFailure) {
      return EntitySettings::load("$entityTypeId.$bundle") ?? EntitySettings::create(['id' => "$entityTypeId.$bundle"]);
    }
    return EntitySettings::load("$entityTypeId.$bundle");
  }

}
